dispose method
void
dispose()
Cancels timers and clears the cache. After calling this, the manager can still be reused.
Implementation
void dispose() => clear();
Cancels timers and clears the cache. After calling this, the manager can still be reused.
void dispose() => clear();