length property
int
get
length
The number of entries currently in the cache, including any that are expired but have not yet been evicted.
Implementation
int get length => _cache.length;
The number of entries currently in the cache, including any that are expired but have not yet been evicted.
int get length => _cache.length;